@@ -9,8 +9,7 @@ import networkx as nx
 from collections import defaultdict
 import netaddr
 import functools
-
-messaging = autonetkit.ank_messaging
+import autonetkit.ank_messaging
 
 #TODO: allow slack in allocations: both for ASN (group level), and for collision domains to allow new nodes to be easily added
 
@@ -21,7 +20,6 @@ except ImportError:
 
 def subnet_size(host_count):
     """Returns subnet size"""
-    import math
     host_count += 2 # network and broadcast
     return int(math.ceil(math.log(host_count, 2)))
 
@@ -131,7 +129,6 @@ class IpTree(object):
 
     def save(self):
         import os
-        import gzip
         archive_dir = os.path.join("versions", "ip")
         if not os.path.isdir(archive_dir):
             os.makedirs(archive_dir)
@@ -285,7 +282,8 @@ class IpTree(object):
 
         # now allocate the IPs
         global_prefix_len = global_root.prefixlen
-        global_ip_block = netaddr.IPNetwork("%s/%s" % (self.root_ip_block, global_prefix_len))
+        #TODO: try/catch if the block is too small for prefix
+        global_ip_block = self.root_ip_block.subnet(global_prefix_len).next()
         self.graph = global_graph
 
 # add children of collision domains
@@ -401,12 +399,6 @@ class IpTree(object):
         edges = [n for n in self if n.is_host() and n.host.src]
         for edge in edges:
             edge.host.ip_address = edge.subnet
-
-#TODO: do we need to store loopback groups into advertise addresses?
-
-        #loopback_groups = [n for n in self if n.is_loopback_group()]
-        #for loopback_group in loopback_groups:
-            #print loopback_group
     
         # don't look at host nodes now - use loopback_groups
         host_tree_nodes = [n for n in self if n.is_host() and n.host.is_l3device]
@@ -423,7 +415,7 @@ class IpTree(object):
         for n in interfaces:
             n.host.loopback = n.subnet
 
-def assign_asn_to_interasn_cds(g_ip):
+def assign_asn_to_interasn_cds(g_ip, address_block = None):
     G_phy = g_ip.overlay("phy")
     for collision_domain in g_ip.nodes("collision_domain"):
         neigh_asn = list(ank_utils.neigh_attr(g_ip, collision_domain, "asn", G_phy)) #asn of neighbors
@@ -435,76 +427,52 @@ def assign_asn_to_interasn_cds(g_ip):
 
     return
 
-def allocate_ips(g_ip, infrastructure = True, loopbacks = True, secondary_loopbacks = False):
-    #TODO: tidy up the below comment and make all arguments default to False
-    """Can disable infrastructure, eg for ipv6, still want to alloc ipv4 loopbacks for router ids"""
-    loopback_tree = []
-    if loopbacks:
-        log.info("Allocating v4 Primary Host loopback IPs")
-        ip_tree = IpTree("192.168.1.0")
-        ip_tree.add_nodes(g_ip.nodes("is_l3device"))
-        ip_tree.build()
-        loopback_tree = ip_tree.json()
-    # json.dumps(ip_tree.json(), cls=autonetkit.ank_json.AnkEncoder, indent = 4)
-        #body = json.dumps({"ip_allocations": jsontree})
-        ip_tree.assign()
-        g_ip.data.loopback_blocks = ip_tree.group_allocations()
+def allocate_infra(g_ip, address_block = None):
+    if not address_block:
+        address_block = netaddr.IPNetwork("10.0.0.0/8")
+    log.info("Allocating v4 Infrastructure IPs")
+    ip_tree = IpTree(address_block)
+    assign_asn_to_interasn_cds(g_ip)
+    ip_tree.add_nodes(g_ip.nodes("collision_domain"))
+    ip_tree.build()
+    #cd_tree = ip_tree.json()
+    ip_tree.assign()
 
-    secondary_loopback_tree = []
-    if secondary_loopbacks:
-        log.info("Allocating v4 Secondary Host loopback IPs")
-        #TODO: trim g_ip.nodes() to g_ip
-        ip_tree = IpTree("172.16.0.0")
-        secondary_loopbacks = [i for n in g_ip.nodes()
-                for i in n.loopback_interfaces
-                if not i.is_loopback_zero]
-
-        ip_tree.add_nodes(secondary_loopbacks)
-        ip_tree.build()
-        secondary_loopback_tree = ip_tree.json()
-    # json.dumps(ip_tree.json(), cls=autonetkit.ank_json.AnkEncoder, indent = 4)
-        ip_tree.assign()
-        #g_ip.data.loopback_blocks = ip_tree.group_allocations()
-
-
-    cd_tree = []
-    if infrastructure:
-        log.info("Allocating v4 Infrastructure IPs")
-        ip_tree = IpTree("10.0.0.0")
-        assign_asn_to_interasn_cds(g_ip)
-        ip_tree.add_nodes(g_ip.nodes("collision_domain"))
-        ip_tree.build()
-        cd_tree = ip_tree.json()
-        ip_tree.assign()
-
-        total_tree = {
-                'name': "ip",
-                'children': 
-                [loopback_tree, secondary_loopback_tree, cd_tree],
-                #[cd_tree],
-                #[secondary_loopback_tree],
-                    #[loopback_tree],
-                }
-        jsontree = json.dumps(total_tree, cls=autonetkit.ank_json.AnkEncoder, indent = 4)
-
-#TODO: use seperate call in post to pass "ip_allocations" rather than in json
-
-    else:
-        cd_tree = {}
-
-    total_tree = {
-            'name': "ip",
-            'children': 
-            [loopback_tree, secondary_loopback_tree, cd_tree],
-            #[cd_tree],
-            #[secondary_loopback_tree],
-                #[loopback_tree],
-            }
-    jsontree = json.dumps(total_tree, cls=autonetkit.ank_json.AnkEncoder, indent = 4)
-    messaging.publish_data(jsontree, "ip_allocations")
-
-
-#TODO: need to update with loopbacks if wish to advertise also - or subdivide blocks?
     g_ip.data.infra_blocks = ip_tree.group_allocations()
 
-    #ip_tree.save()
+    #total_tree = { 'name': "ip", 'children': [cd_tree], }
+    #jsontree = json.dumps(total_tree, cls=autonetkit.ank_json.AnkEncoder, indent = 4)
+    g_ip.data.infra_blocks = ip_tree.group_allocations()
+
+#TODO: apply directly here
+
+
+def allocate_loopbacks(g_ip, address_block = None):
+    if not address_block:
+        address_block = netaddr.IPNetwork("192.168.0.0/22")
+    log.info("Allocating v4 Primary Host loopback IPs")
+    ip_tree = IpTree(address_block)
+    ip_tree.add_nodes(g_ip.nodes("is_l3device"))
+    ip_tree.build()
+    #loopback_tree = ip_tree.json()
+    ip_tree.assign()
+    g_ip.data.loopback_blocks = ip_tree.group_allocations()
+
+def allocate_vrf_loopbacks(g_ip, address_block = None):
+    if not address_block:
+        address_block = netaddr.IPNetwork("172.16.0.0/24")
+    log.info("Allocating v4 Secondary Host loopback IPs")
+    ip_tree = IpTree(address_block)
+    secondary_loopbacks = [i for n in g_ip.nodes()
+            for i in n.loopback_interfaces
+            if not i.is_loopback_zero
+            ]
+
+    vrf_loopbacks = [i for i in secondary_loopbacks
+            if i['vrf'].vrf_name]
+
+    ip_tree.add_nodes(vrf_loopbacks)
+    ip_tree.build()
+    #secondary_loopback_tree = ip_tree.json()
+    ip_tree.assign()
+    #TODO: store vrf block to g_ip.data
